@@ -81,7 +81,7 @@ void FamInterface::AddPerson(int mal, int yob, int ischi, int *index, int *error
    male[nPersons]         = mal;
    isChild[nPersons]      = ischi; 
    internalPersonName[nPersons] = new char[100]; 
-   sprintf(internalPersonName[nPersons], "%d", ++counter); 
+   snprintf(internalPersonName[nPersons], 100, "%d", ++counter);
    YOB[nPersons]          = yob; 
    *index = nPersons; 
    int internalError = 0; 
@@ -508,13 +508,13 @@ void FamInterface::AddAlleleSystem(int nAll,
    nAlleles = newAlleles; 
    internalAlleleName = newintAll; 
    internalSystemName[nSystems] = new char[100]; 
-   sprintf(internalSystemName[nSystems], "%d", ++counter); 
+   snprintf(internalSystemName[nSystems], 256, "%d", ++counter);
    nAlleles[nSystems] = nAll; 
    internalAlleleName[nSystems] = new char*[nAll]; 
    for (i=0; i<nAll; i++)
    {
       internalAlleleName[nSystems][i] = new char[100]; 
-      sprintf(internalAlleleName[nSystems][i], "%d", ++counter); 
+      snprintf(internalAlleleName[nSystems][i], 256, "%d", ++counter);
    }
    
    int paterError = 0; 
@@ -701,7 +701,7 @@ void FamInterface::EditAlleleSystem(int indexSystem,
       if (newAlls[i])
       {
 	 internalAlleleName[indexSystem][i] = new char[100]; 
-	 sprintf(internalAlleleName[indexSystem][i], "%d", ++counter); 
+	 snprintf(internalAlleleName[indexSystem][i], 256, "%d", ++counter);
       }
    nAlleles[indexSystem] = nAll; 
    delete[] newAlls; 
