@@ -5,6 +5,7 @@
 #include "odds.h"
 #include "special.h"
 
+
 void Linked_list::print(int indent) {
   Link* lk = first;
   while (lk) {
@@ -63,6 +64,10 @@ int Linked_list::n_elements() {
   return result;
 }
 
+// This should directly precede the pcopy constructor
+#if defined(__clang__) || __GNUC__ >= 8
+  __attribute__((no_sanitize("vptr")))
+#endif
 pcopy::pcopy(person* p, int is_collapsed) : 
 alias(p), male(p->is_male()), mother(0), father(0), 
 child(0), paternal_sibling(0), maternal_sibling(0) {
